/**
 * 
 */
package es.accv.arangi.client;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.security.Policy;

import javax.swing.JApplet;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.UIManager;

import org.apache.log4j.ConsoleAppender;
import org.apache.log4j.Level;
import org.apache.log4j.Logger;
import org.apache.log4j.PatternLayout;

import es.accv.arangi.base.ArangiObject;
import es.accv.arangi.base.util.Util;
import es.accv.arangi.client.util.I18n;

/**
 * Clase genrica para los applets
 * 
 * @author <a href="mailto:jgutierrez@accv.es">Jos M Gutirrez</a>
 */
public class ArangiClientApplet extends JApplet {

	/**
	 * Serial Version UID
	 */
	private static final long serialVersionUID = 1L;
	
	/*
	 * Logger de la clase
	 */
	protected static Logger logger = Logger.getLogger(ArangiClientSignatureApplet.class);
	
	/*
	 * i18n
	 */
	protected I18n i18n;
	
	/*
	 * Error
	 */
	protected Throwable error;
	
	/*
	 * Directorio donde se ha producido el ltimo guardado
	 */
	File currentSaveDirectory;
	
	/*
	 * Directorio del path al ltimo fichero
	 */
	File currentGetPathDirectory;
	
	/**
	 * Inicializacin esttica: policy, log4j, skin
	 */
	static {
		//-- Modificar el policy
		System.out.println ("Modificando el policy");
		System.setProperty("java.security.policy", getPolicyPath());
		Policy.getPolicy().refresh();
		
		//-- Deshabilitamos la inicializacin por defecto de log4j
		System.setProperty("log4j.defaultInitOverride", "true");
		
		//-- Configuramos a mano
		ConsoleAppender appender = new ConsoleAppender();
		appender.setWriter(new PrintWriter(System.out));
		appender.setThreshold(Level.DEBUG);
		PatternLayout layout = new PatternLayout();
		layout.setConversionPattern("[%d{dd-MM-yyyy HH:mm:ss}] %m%n");
		appender.setLayout(layout);
		Logger.getRootLogger().addAppender(appender);
		Logger.getRootLogger().setLevel(Level.DEBUG);
		
		logger = Logger.getLogger(ArangiClientApplet.class);
		logger.removeAllAppenders();
		logger.addAppender(appender);
		logger.debug("Log listo");
		
		//-- Skin
		String lookandfeel = UIManager.getSystemLookAndFeelClassName(); 
		try {
	        UIManager.setLookAndFeel(lookandfeel);
			logger.debug("Establecido el skin '" + lookandfeel + "'");
	    } catch(Throwable e) {
			logger.info ("No se ha podido establecer el skin '" + lookandfeel + "'", e);
		}
		JDialog.setDefaultLookAndFeelDecorated(true);
		javax.swing.JFrame.setDefaultLookAndFeelDecorated(true);

	}

	/*
	 * Deja en la carpeta del usuario el fichero de polticas y devuelve su path
	 */
	private static String getPolicyPath() {
		
		InputStream is = ArangiClient.class.getClassLoader().getResourceAsStream("java.policy");
		
		try {
			File file = ArangiObject.saveToArangiTemporalFolder(is, "java.policy");
			return file.getAbsolutePath();
		} catch (IOException e) {
			logger.info ("[getPolicyPath]::No se ha podido guardar el fichero de poltica", e);
		}
		
		return null;
	}

	/**
	 * Mtodo que guarda el documento pasado como parmetro en el lugar del disco que
	 * indique el usuario. El documento se guardara tras decodificar el base64
	 * 
	 * @param documentB64 Documento en base64 a guardar
	 * @return Si se guarda se devuelve cierto, no en caso de error o que el usuario
	 * 	no elija donde guardar.
	 */
	public boolean save (String documentB64) {
		logger.info("[ArangiClientSignatureApplet.save]::Entrada");
		this.error = null;
		
		//-- Mostrar dilogo para obtener el path donde se guardar el documento
		JFileChooser jfc = new JFileChooser(currentSaveDirectory);
		jfc.setDialogTitle(i18n.getString("titulo.elegir.path.guardar"));
		int ret = jfc.showOpenDialog(null);
		if (ret == JFileChooser.APPROVE_OPTION) {
			String path = jfc.getSelectedFile().getAbsolutePath();
			logger.debug("[ArangiClientSignatureApplet.save]::Se guardar en: " + path);
			File file = new File (path);
			try {
				Util.saveFile(file, Util.decodeBase64(documentB64));
				logger.info("[ArangiClientSignatureApplet.save]::Documento guardado en " + file);
				currentSaveDirectory = file.getParentFile();
				return true;
			} catch (IOException e) {
				logger.error ("[ArangiClientSignatureApplet.save]::ERROR guardando", e);
				this.error = e;
				return false;
			}
		} else {
			logger.info("[ArangiClientSignatureApplet.save]::El usuario no elige un path donde guardar la firma");
			return false;
		}
	}
	
	
}
