/**
 * 
 */
package es.accv.arangi.client;

import javax.swing.JOptionPane;

import org.apache.log4j.Logger;

import es.accv.arangi.base.certificate.Certificate;
import es.accv.arangi.base.signature.ISignature;
import es.accv.arangi.client.exception.SignatureCancelledByUserException;
import es.accv.arangi.client.util.I18n;

/**
 * Objeto que se carga con un contenedor de firmas y que tiene como objeto que 
 * el usuario elija una de las firmas que contiene.
 * 
 * @author <a href="mailto:jgutierrez@accv.es">Jos M Gutirrez</a>
 */
public class SignatureSelector {

	/*
	 * Logger de la clase
	 */
	Logger logger = Logger.getLogger(SignatureSelector.class);
	
	
	/*
	 * i18n
	 */
	I18n i18n;
	
	/*
	 * Objeto firma
	 */
	ISignature signatureObject;
	
	/**
	 * Constructor
	 * 
	 * @param i18n i18n 
	 * @param signatureObject Objeto firma
	 */
	public SignatureSelector(I18n i18n, ISignature signatureObject) {
		this.i18n = i18n;
		this.signatureObject = signatureObject;
	}

	/**
	 * Obtiene todos los certificados de firma del objeto firma.
	 * Si slo hay uno lo devuelve. Si hay ms de uno muestra
	 * una pantalla para que el usuario elija uno de ellos.
	 * 
	 * @return Certificado de una de las firmas
	 * @throws SignatureCancelledByUserException El usuario no desea elegir un certificado
	 * 	de la lista
	 */
	public Certificate getCertificateSignature() throws SignatureCancelledByUserException {
		logger.info("[SignatureSelector.getCertificateSignature]::Entrada");
		
		//-- Obtener los certificados de las firmas
		Certificate[] arrayCertificates = signatureObject.getCertificates();
		logger.info("[SignatureSelector.getCertificateSignature]::El objeto contiene " + arrayCertificates.length + " firmas");
		
		//-- Si slo hay una firma devolver su certificado
		if (arrayCertificates.length == 1) {
			return arrayCertificates[0];
		}
		
		//-- Si hay ms de un certificado mostrar listado al usuario para que elija
		String[] arrayEtiquetasCertificados = new String[arrayCertificates.length];
		for (int i = 0; i < arrayCertificates.length; i++) {
			arrayEtiquetasCertificados[i] = arrayCertificates[i].getCommonName();
		}
		
		String etiquetaCertificadoElegido;
		while (true) {
			etiquetaCertificadoElegido = (String)JOptionPane.showInputDialog(null, i18n.getString("texto.seleccione.lista.contrafirmar"),
					i18n.getString("titulo.elegir.certificado.contrafirmar"), JOptionPane.PLAIN_MESSAGE, null, arrayEtiquetasCertificados, null);
			logger.debug("[SignatureSelector.getCertificateSignature]::El certificado elegido ha sido: " + etiquetaCertificadoElegido);
			
			//-- Si no se ha elegido nada preguntar
			if (etiquetaCertificadoElegido == null) {
				if (JOptionPane.showConfirmDialog(null, i18n.getString("pregunta.no.elegido.certificado"), 
						i18n.getString("pregunta.no.elegido.certificado"), JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION) {

					logger.debug("[SignatureSelector.getCertificateSignature]::El usuario no desea elegir un certificado y continuar con la firma");
					throw new SignatureCancelledByUserException(i18n.getString("error.usuario.cancela.firma"));	
				}
			} else {
				//-- El usuario ha elegido un certificado de la lista
				break;
			}
		}

		//-- Buscar el index en la lista del certificado elegido
		for (int index = 0; index < arrayEtiquetasCertificados.length; index++) {
			if (arrayEtiquetasCertificados[index].equals(etiquetaCertificadoElegido)) {
				return arrayCertificates[index];
			}
		}
		
		//-- No se debe llegar aqu
		logger.debug("[SignatureSelector.getCertificateSignature]::La etiqueta del usuario no coindice con ninguna de la lista");
		return null;
	}

	
	
}
