/**
 * 
 */
package es.accv.arangi.client.model;

import es.accv.arangi.base.certificate.validation.ValidateCertificate;
import es.accv.arangi.certificate.CertificadoAplicacion;
import es.accv.arangi.certificate.CertificadoCiudadano;
import es.accv.arangi.certificate.CertificadoDNIe;
import es.accv.arangi.certificate.CertificadoEmpleadoPublico;
import es.accv.arangi.certificate.CertificadoEntidad;
import es.accv.arangi.certificate.CertificadoPersona;
import es.accv.arangi.certificate.CertificadoPertenenciaEmpresa;
import es.accv.arangi.certificate.CertificadoSello;

/**
 * Clase bean para la informacin obtenida de un certificado firmante
 * 
 * @author <a href="mailto:jgutierrez@accv.es">Jos M Gutirrez</a>
 */
public class SignerInformation {

	String tipoCertificado;
	String nif;
	String name;
	String email;
	String position;
	String cif;
	String entity;
	String organizationalUnit;
	String nrpnip;
	String agentName;
	String agentNIF;
	
	public SignerInformation (ValidateCertificate valCert) {
		//-- Certificado de persona
		if (valCert instanceof CertificadoPersona) {
			CertificadoPersona certificate = (CertificadoPersona) valCert;
			
			this.name = certificate.getName() + " " + certificate.getSurnames();
			this.nif = certificate.getNIF();
			this.email = certificate.getEmail();
			
			if (certificate instanceof CertificadoEmpleadoPublico) {
				CertificadoEmpleadoPublico certificadoEP = (CertificadoEmpleadoPublico) certificate;
				this.tipoCertificado = "certificado.tipo.ep";
				this.position = certificadoEP.getPosition();
				this.cif = certificadoEP.getEntityCIF();
				this.entity = certificadoEP.getEntityName();

				if (certificadoEP.getOrganizationalUnit() != null) {
					this.organizationalUnit = certificadoEP.getOrganizationalUnit();
				}
				if (certificadoEP.getNRP() != null) {
					this.nrpnip = certificadoEP.getNRP();
				}
			}
			
			if (certificate instanceof CertificadoPertenenciaEmpresa) {
				CertificadoPertenenciaEmpresa certificadoPE = (CertificadoPertenenciaEmpresa) certificate;
				this.tipoCertificado = "certificado.tipo.pe";
				this.position = certificadoPE.getPosition();
				this.cif = certificadoPE.getEntityCIF();
				this.entity = certificadoPE.getEntityName();

				if (certificadoPE.getOrganizationalUnit() != null) {
					this.organizationalUnit = certificadoPE.getOrganizationalUnit();
				}
				if (certificadoPE.getIDNumber() != null) {
					this.nrpnip = certificadoPE.getIDNumber();
				}
			}
			
			if (certificate instanceof CertificadoCiudadano) {
				this.tipoCertificado = "certificado.tipo.ciudadano";
			} 
			if (certificate instanceof CertificadoDNIe) {
				this.tipoCertificado = "certificado.tipo.dnie";
			}
		}
		
		//-- Certificado de entidad
		if (valCert instanceof CertificadoEntidad) {
			CertificadoEntidad certificate = (CertificadoEntidad) valCert;
			
			this.tipoCertificado = "certificado.tipo.entidad";
			this.name = certificate.getName();
			this.cif = certificate.getCIF();
			this.email = certificate.getEmail();
			this.agentName = certificate.getAgentName() + " " + certificate.getAgentSurnames();
			this.agentNIF = certificate.getAgentNIF();
		}
		
		//-- Certificado de aplicacin
		if (valCert instanceof CertificadoAplicacion) {
			CertificadoAplicacion certificate = (CertificadoAplicacion) valCert;
			
			this.tipoCertificado = "certificado.tipo.aplicacion";
			this.name = certificate.getName();
			this.agentName = certificate.getResponsibleName() + " " + certificate.getResponsibleSurnames();
			this.email = certificate.getEmail();
		}
		
		//-- Certificado de sello de rgano
		if (valCert instanceof CertificadoSello) {
			CertificadoSello certificate = (CertificadoSello) valCert;
			
			this.tipoCertificado = "certificado.tipo.sello";
			this.name = certificate.getName();
			this.cif = certificate.getEntityNIF();
			this.entity = certificate.getEntityName();
			this.email = certificate.getEmail();
		}
		
		if (this.tipoCertificado == null) {
			this.tipoCertificado = "certificado.tipo.desconocido";
		}
	}
	
	public String getNif() {
		return nif;
	}
	public void setNif(String nif) {
		this.nif = nif;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getEmail() {
		return email;
	}
	public void setEmail(String email) {
		this.email = email;
	}
	public String getPosition() {
		return position;
	}
	public void setPosition(String position) {
		this.position = position;
	}
	public String getCif() {
		return cif;
	}
	public void setCif(String cif) {
		this.cif = cif;
	}
	public String getEntity() {
		return entity;
	}
	public void setEntity(String entity) {
		this.entity = entity;
	}
	public String getOrganizationalUnit() {
		return organizationalUnit;
	}
	public void setOrganizationalUnit(String organizationalUnit) {
		this.organizationalUnit = organizationalUnit;
	}
	public String getNrpnip() {
		return nrpnip;
	}
	public void setNrpnip(String nrpnip) {
		this.nrpnip = nrpnip;
	}
	public String getAgentName() {
		return agentName;
	}
	public void setAgentName(String agentName) {
		this.agentName = agentName;
	}
	public String getAgentNIF() {
		return agentNIF;
	}
	public void setAgentNIF(String agentNIF) {
		this.agentNIF = agentNIF;
	}

	public String getTipoCertificado() {
		return tipoCertificado;
	}

	public void setTipoCertificado(String tipoCertificado) {
		this.tipoCertificado = tipoCertificado;
	}
	
	
}
