package es.accv.arangi.client.model;

import java.util.Date;

import org.apache.log4j.Logger;

import es.accv.arangi.base.certificate.validation.OCSPResponse;
import es.accv.arangi.base.certificate.validation.ValidateCertificate;
import es.accv.arangi.base.exception.certificate.NormalizeCertificateException;
import es.accv.arangi.base.timestamp.TimeStamp;
import es.accv.arangi.base.util.validation.ValidationResult;
import es.accv.arangi.certificate.CertificateFactory;
import es.accv.arangi.client.util.I18n;

/**
 * Objeto resultado de una validacin.
 * 
 * @author <a href="mailto:jgutierrez@accv.es">Jos M Gutirrez</a>
 */
public class ValidationObject {

	Logger logger = Logger.getLogger(ValidationObject.class);
	
	/*
	 * Tipo de firma
	 */
	String signatureType;
	
	/*
	 * Resultados
	 */
	SignatureValidationResult[] signatureValidationResults;
	
	//-- Constructor
	
	public ValidationObject (String signatureType, ValidationResult[] validationResults, I18n i18n) {
		this.signatureType = signatureType;
		signatureValidationResults = new SignatureValidationResult[validationResults.length];
		for (int i = 0; i < validationResults.length; i++) {
			signatureValidationResults[i] = new SignatureValidationResult (validationResults[i], i18n);
		}
	}
	
	//-- GET/SET
	
	public String getSignatureType() {
		return signatureType;
	}

	public void setSignatureType(String signatureType) {
		this.signatureType = signatureType;
	}

	public SignatureValidationResult[] getSignatureValidationResults() {
		return signatureValidationResults;
	}

	public void setSignatureValidationResults(
			SignatureValidationResult[] signatureValidationResults) {
		this.signatureValidationResults = signatureValidationResults;
	}	
	
	//-- Clases
	
	public class SignatureValidationResult {
		boolean valid;
		int result;
		String invalidMessage;
		SignerInformation signerInformation;
		ValidateCertificate certificate;
		Date date;
		TimeStamp timeStamp;
		OCSPResponse[] ocspResponses;
		SignatureValidationResult[] counterSignatures;
		
		//-- Constructores
		
		public SignatureValidationResult(ValidationResult validationResult, I18n i18n) {
			this.valid = validationResult.isValid();
			this.invalidMessage = i18n.getString("resultado.validacion.arangi." + validationResult.getResult());
			this.date = validationResult.getDate();
			this.timeStamp = validationResult.getTimeStamp();
			this.ocspResponses = validationResult.getOcspResponses();
			this.valid = validationResult.isValid();
			this.result = validationResult.getResult();
			
			//-- Obtener el certificado
			try {
				certificate = CertificateFactory.getInstance(validationResult.getCertificate());
			} catch (NormalizeCertificateException e) {
				logger.error("[ValidationObject]::No se ha podido normalizar el certificado::" + validationResult.getCertificate());
				return;
			}
			
			//-- Obtener informacin del certificado
			signerInformation = new SignerInformation(certificate);
			
			//-- Contrafirmas
			if (validationResult.getCounterSignatures() == null) {
				this.counterSignatures = new SignatureValidationResult[0];
			} else {
				this.counterSignatures = new SignatureValidationResult[validationResult.getCounterSignatures().length];
				for (int i = 0; i < validationResult.getCounterSignatures().length; i++) {
					this.counterSignatures[i] = new ValidationObject.SignatureValidationResult(validationResult.getCounterSignatures()[i], i18n);
				}
			}
		}
		
		
		//-- GET/SET
		
		public boolean isValid() {
			return valid;
		}
		public void setValid(boolean valid) {
			this.valid = valid;
		}
		public int getResult() {
			return result;
		}
		public void setResult(int result) {
			this.result = result;
		}
		public String getInvalidMessage() {
			return invalidMessage;
		}
		public void setInvalidMessage(String invalidMessage) {
			this.invalidMessage = invalidMessage;
		}
		public Date getDate() {
			return date;
		}
		public void setDate(Date date) {
			this.date = date;
		}
		public TimeStamp getTimeStamp() {
			return timeStamp;
		}
		public void setTimeStamp(TimeStamp timeStamp) {
			this.timeStamp = timeStamp;
		}
		public OCSPResponse[] getOcspResponses() {
			return ocspResponses;
		}
		public void setOcspResponse(OCSPResponse[] ocspResponses) {
			this.ocspResponses = ocspResponses;
		}
		public SignatureValidationResult[] getCounterSignatures() {
			return counterSignatures;
		}
		public void setCounterSignatures(SignatureValidationResult[] counterSignatures) {
			this.counterSignatures = counterSignatures;
		}
		public SignerInformation getSignerInformation() {
			return signerInformation;
		}
		public void setSignerInformation(SignerInformation signerInformation) {
			this.signerInformation = signerInformation;
		}
		public ValidateCertificate getCertificate() {
			return certificate;
		}
		public void setCertificate(ValidateCertificate certificate) {
			this.certificate = certificate;
		}
	}

}
