/**
 * Copyright 2012 Agencia de Tecnologa y Certificacin Electrnica
 */
package es.accv.arangi.client.signature;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.HashMap;
import java.util.Map;

import es.accv.arangi.base.signature.util.XAdESDataObjectFormat;
import es.accv.arangi.client.ArangiClient;
import es.accv.arangi.timestamp.TimeStamp;

/**
 * Clase base de todas las factory de firmas
 * 
 * @author <a href="mailto:jgutierrez@accv.es">Jos Manuel Gutirrez Nez</a>
 *
 */
public abstract class BaseSignatureFactory implements ArangiClientSignatureFactory {

	protected Map<String, Object> options = new HashMap<String, Object>();
	
	/*
	 * URL a la TSA
	 */
	protected String urlTSA = TimeStamp.URL_ACCV_TSA_SERVER;
	
	/* (non-Javadoc)
	 * @see es.accv.arangi.client.signature.ArangiClientSignatureFactory#setSignatureOptions(java.util.Map)
	 */
	public void setSignatureOptions(Map<String, Object> options) {
		this.options = options;
	}

	/**
	 * Cambia el valor de la TSA a utilizar
	 */
	public void setUrlTSA (String urlTSA) {
		this.urlTSA = urlTSA;
	}
	
	/**
	 * A partir de los parmetros extra construye un objeto que se aade a la firma
	 * para describir el documento firmado
	 */
	protected XAdESDataObjectFormat getDofFromOptions() {
		
		if (options == null) {
			return null;
		}
		if (options.containsKey (ArangiClient.OPCION_DESCRIPTION) && !(options.get(ArangiClient.OPCION_DESCRIPTION) instanceof String)) {
			options.remove(ArangiClient.OPCION_DESCRIPTION);
		}
		if (options.containsKey (ArangiClient.OPCION_MIME) && !(options.get(ArangiClient.OPCION_MIME) instanceof String)) {
			options.remove(ArangiClient.OPCION_MIME);
		}
		if (options.containsKey (ArangiClient.OPCION_ENCODING) && !(options.get(ArangiClient.OPCION_ENCODING) instanceof String)) {
			options.remove(ArangiClient.OPCION_ENCODING);
		} 
		URI encoding = null;
		if (options.containsKey (ArangiClient.OPCION_ENCODING)) {
			try {
				encoding = new URI ((String)options.get(ArangiClient.OPCION_ENCODING));
			} catch (URISyntaxException e) {
			}
		}
		if (!options.containsKey(ArangiClient.OPCION_DESCRIPTION) && !options.containsKey(ArangiClient.OPCION_MIME) 
				&& !options.containsKey(ArangiClient.OPCION_ENCODING)) {
			return null;
		}
		XAdESDataObjectFormat dof = new XAdESDataObjectFormat((String)options.get(ArangiClient.OPCION_DESCRIPTION), null,
				(String)options.get(ArangiClient.OPCION_MIME), encoding);
		
		return dof;
	}


}
