package es.accv.arangi.client.validation;

import java.io.File;
import java.io.InputStream;

import org.apache.log4j.Logger;

import es.accv.arangi.base.signature.ISignature;
import es.accv.arangi.client.ValidationConstants;
import es.accv.arangi.client.util.I18n;
import es.accv.arangi.signature.PKCS7Signature;

/**
 * Clase que realiza validaciones PKCS#7
 * 
 * @author <a href="mailto:jgutierrez@accv.es">Jos M Gutirrez</a>
 */
public class Pkcs7ValidationFactory extends ArangiClientValidationFactory {
	
	/*
	 * Logger de la clase
	 */
	Logger logger = Logger.getLogger(Pkcs7ValidationFactory.class);
	
	/**
	 * Constructor 
	 * 
	 * @param i18n Internacionalizacin
	 */
	public Pkcs7ValidationFactory (I18n i18n) {
		super (i18n);
	}

	//-- Implementacin de los mtodos abstractos
	
	/*
	 * Obtiene un objeto para tratar la firma adecuada inicializado con un fichero.
	 * 
	 * @param signature Fichero con la firma
	 * @return Objeto para tratar la firma
	 * @throws Exception Error cargando la firma
	 */
	protected ISignature getSignatureObject(File signature) throws Exception {
		return new PKCS7Signature(signature);
	}

	/*
	 * Obtiene un objeto para tratar la firma adecuada inicializado con un array de bytes.
	 * 
	 * @param signature Contenido de la firma
	 * @return Objeto para tratar la firma
	 * @throws Exception Error cargando la firma
	 */
	protected ISignature getSignatureObject(byte[] signature) throws Exception {
		return new PKCS7Signature(signature);
	}

	/*
	 * Obtiene un objeto para tratar la firma adecuada inicializado con un stream de lectura.
	 * 
	 * @param isSignature Stream al fichero de la firma
	 * @return Objeto para tratar la firma
	 * @throws Exception Error cargando la firma
	 */
	protected ISignature getSignatureObject(InputStream isSignature) throws Exception {
		return new PKCS7Signature(isSignature);
	}

	/*
	 * Obtiene en texto el tipo de firma que se est tratando
	 * 
	 * @return tipo de firma
	 */
	protected String getSignatureType() {
		return ValidationConstants.SIGNATURE_PKCS7;
	}


}
