/**
 * 
 */
package es.accv.arangi.client.xstream;

import java.io.ByteArrayInputStream;
import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.apache.log4j.Logger;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;

import com.thoughtworks.xstream.XStream;
import com.thoughtworks.xstream.io.xml.DomDriver;
import com.thoughtworks.xstream.io.xml.DomReader;

import es.accv.arangi.client.model.SignerInformation;

/**
 * Utilidad de parseo del XML devuelto como respuesta de una validacin
 * 
 * @author <a href="mailto:jgutierrez@accv.es">Jos M Gutirrez</a>
 */
public class ValidationResultUtil {
	
	/*
	 * Logger de la clase
	 */
	static Logger logger = Logger.getLogger(ValidationResultUtil.class);

	/**
	 * Obtiene una versin POJO del xml pasado como parmetro, que ser el resultado
	 * de la operacin de validar firma del cliente de Arang.
	 * 
	 * @param xml XML resultado de la validacin
	 * @return Objeto representativo del XML
	 * @throws ParserConfigurationException El XML no puede ser parseado, aparentemente no
	 * 	coincide con un XML de respuesta de validacin de firma
	 * @throws IOException Error de entrada/salida
	 * @throws SAXException Error durante el parseo del XML (probablemente no se trate de un
	 * 	XML bien formado)
	 */
	public static XStreamValidationResult getValidationResultObject (String xml) throws ParserConfigurationException, SAXException, IOException {
		
		DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
		DocumentBuilder builder = dbf.newDocumentBuilder();
		Document document = builder.parse(new ByteArrayInputStream(xml.getBytes("UTF-8")));
		
		XStream xstream = new XStream(new DomDriver());
		xstream.alias("validation_result", XStreamValidationResult.class);
		xstream.alias("signature", XStreamSignature.class);
		xstream.alias("countersignature", XStreamSignature.class);
		xstream.alias("signer_information", SignerInformation.class);
		xstream.alias("timestamp", XStreamTimestamp.class);
		xstream.alias("validity", XStreamValidity.class);
		xstream.alias("ocsp", XStreamOcsp.class);
		
		return (XStreamValidationResult) xstream.unmarshal(new DomReader(document));
	}
	
	/**
	 * Obtiene una versin POJO del xml pasado como parmetro, que ser el resultado
	 * de la operacin de validar certificado del cliente de Arang.
	 * 
	 * @param xml XML resultado de la validacin
	 * @return Objeto representativo del XML
	 * @throws ParserConfigurationException El XML no puede ser parseado, aparentemente no
	 * 	coincide con un XML de respuesta de validacin de firma
	 * @throws IOException Error de entrada/salida
	 * @throws SAXException Error durante el parseo del XML (probablemente no se trate de un
	 * 	XML bien formado)
	 */
	public static XStreamCertificateResult getCertificateResultObject (String xml) throws ParserConfigurationException, SAXException, IOException {
		
		DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
		DocumentBuilder builder = dbf.newDocumentBuilder();
		Document document = builder.parse(new ByteArrayInputStream(xml.getBytes("UTF-8")));
		
		XStream xstream = new XStream(new DomDriver());
		xstream.alias("certificate_result", XStreamCertificateResult.class);
		xstream.alias("subject_information", SignerInformation.class);
		xstream.alias("validity", XStreamValidity.class);
		
		return (XStreamCertificateResult) xstream.unmarshal(new DomReader(document));
	}

}
